#version 3.7;

#declare RAD = 16;
                
global_settings {
        assumed_gamma 1
        max_trace_level 5
        noise_generator 3 
        #if(RAD > 0)
                radiosity {
                        pretrace_start 0.08
                        pretrace_end   0.04/RAD
                        count 60*RAD                
                        nearest_count min (20,RAD)      
                        error_bound 2/RAD
                        low_error_factor 0.5      
                        recursion_limit 1      
                        gray_threshold 0  
                        minimum_reuse 0.015 
                        brightness 1      
                        adc_bailout 0.005
                        normal on
                        media off
                }
        #end
}        

#include "stdinc.inc"
#include "functions.inc"

// studio lighting setup by Jaimes Vives Piqueres  http://www.ignorancia.org/en/index.php?page=Studio_Lighting

#declare use_blur    = 7*0;  
#ifndef(use_radiosity) 
        #declare use_radiosity = 1;  
#end          

#include "CIE.inc"
CIE_ColorSystemWhitepoint (sRGB_ColSys, Illuminant_D65)
#include "lightsys.inc" 
#include "lightsys_constants.inc" 
#declare Lightsys_Brightness = 0.015*0.7; 

#include "i_studio_room.inc"
#include "i_studio_lighting.inc"

#declare predefined_studio_setup = 1;  
#include "i_studio_sets.inc"     

#declare t_backdrop2 =
texture {
        pigment {Gray10} 
        #if (use_radiosity < 2)
                finish {reflection {0.1, 0.33}}
        #end
}

#include "i_studio_backdrop.inc"
object {backdrop scale 60 translate 80*y}

#declare cl = <1,45+80,-95>;
#declare cd = 5*z; 
#declare la = <-4,17+80,0>;
camera {
        location cl
        up 3.2*y right 3.2*16/9*x
        direction cd
        look_at la
        #if (use_blur)
                focal_point la-12*z
                aperture pi*2
                blur_samples use_blur
        #end
}

//******************************************************

// a variation of a grat material made by Ive  POV 3.7 metals.inc; post your textures here  http://news.povray.org/povray.binaries.images/message/%3C49d21bbf%40news.povray.org%3E/#%3C49d21bbf%40news.povray.org%3E 

// some micro normals

#declare P_Micro1 = 
pigment {
        granite 
        turbulence 0
        color_map {
                [0      rgb 0.3]
                [1      rgb 0.7]
        }
        scale 0.003
}


#declare P_Micro2 = 
pigment {
        onion 
        turbulence 0.5
        color_map {
                [0      rgb 1]
                [0.45   rgb 0.99]
                [0.55   rgb 0.96]
                [1      rgb 0.95]
        }
        scale 0.01
}



#declare P_Macro1 = 
pigment {
        crackle 
        turbulence 1
        color_map {
                [0      rgb 0.3]
                [0.01   rgb 0.3]
                [0.02   rgb 0.7]
                [1      rgb 0.7]
        }
        scale 2
}

// "micro"-normals for blurred reflection - to get some highlights
#macro P_Polish (Polish)

pigment_pattern {
        average
        pigment_map {
                [1      P_Micro1 translate x*20]
                [1      P_Micro1 translate y*20]
                [1      P_Micro1 translate z*20]
                [1      P_Micro2 translate -x*20]
                [1      P_Micro2 translate -y*20]
                [1      P_Micro2 translate -z*20]
        }
}
1-Polish

#end

#macro P_Dents2 (Dents) 

#declare f_rad = function {pattern {radial}}
#declare f_pig = function {pattern {crackle form <1,0,0>}}

pigment_pattern {
        function {f_pig (x-f_rad (x,y,z), y-f_rad (x,y,z), z-f_rad (x,y,z))}
        color_map {
                [0      rgb 0]
                [0.65   rgb 1]
        }
}
Dents
scale 0.7
accuracy 0.003

#end

#macro N_Pattern (Polish, Dents)

normal {
        average
        normal_map {
                [1      P_Polish (Polish)]
                [1      P_Dents2 (Dents)]
        }
}

#end

#macro MaterialSilver (Polish, Dents)

material {
        texture {
                pigment {color srgb <0.9284,0.9016,0.8678>}
                N_Pattern (Polish, Dents)
                finish {
                        ambient 0  
                        diffuse 0.1
                        specular 1 
                        roughness 0.0003
	                phong 0.5 
                        phong_size 10 
                        brilliance 3
                        reflection {0.6, 1 fresnel on metallic}
                        conserve_energy
                }
        }
        interior {ior 3.64}
}

#end

//******************************************************

union {
        object {
                Align_Object ( 
                        Center_Object (Bevelled_Text ("crystal.ttf", "POV", 3, 45, 0.025, 0.25, 0, no), x)
                        -y, <0,0,0>
                )
                scale 2
                translate <-3.2,0,-2.5>               
                scale 10
        }
        object {
                Wire_Box (<-2.6,0,-0.1>, <1.1,3.6,1.8>, 0.05, no)
                translate <-4.1,0,1.5>                
                scale 10
        }
        object {
                Round_Box (<-2.5,0,0>, <1,3.5,1.7>, 0.25, no)
                translate <-4.1,0,1.5>                
                scale 10
        }
        #declare MyFunction = function {pattern {bumps scale 0.2}}      
        object {
                HF_Sphere (MyFunction, off, off, <60,60>, on, "", <0,0.6,0>, 0.4, 0.4)
                scale 16 
                translate <-10.8,0,-12>  
        }
        object {
                HF_Cylinder (MyFunction, off, off, <60,60>, on, "", <0.5,0,0.5>, <0.5,1,0.5>, 0.4, 0.3)
                translate <1.5,0,0>                 
                scale 20
        }
        object {
                HF_Torus (MyFunction, off, off, <60,60>, on, "", 0.5, 0.1, 0.3)
                translate <1.4,0.25,-1>               
                scale 15
        }
        merge {
                torus {0.5, 0.5 scale <1,2,1>}
                cylinder {-y, y, 0.5}       
                scale 20 
                translate <4.5,20,14>
        }
        translate 80*y
        MaterialSilver (0.9, 6)
}
